# reNotize
A utility script for quickly and automatically notarizing Ren'Py applications for macOS.

reNotize supports the entire pipeline of app notarization, starting with the basic ZIP file generated by Ren'Py's build process and automatically generating a fully-notarized DMG for distribution to your users.

## Installation
reNotize can be installed via pip:
```bash
$ pip install renotize
```

Please note that reNotize requires Python 3 and will not provide backwards compatibility for Python 2 for the foreseeable future.

## Usage
```
Usage: renotize.py [OPTIONS] PROJECT COMMAND [ARGS]...

  A utility script for quickly and automatically notarizing Ren'Py
  applications for macOS.

  Commands can be abbreviated by the shortest unique string.

  For example:
      unpack-app -> u
      sign-app -> sign-a
      sign-dmg -> sign-d

  The fully automatic process can be started using:
      renotize -c <path_to_config> <path_to_ZIP_file> full-run

Options:
  -c, --config TEXT
  -d, --debug / -nd, --no-debug  Print debug information or only regular
                                 output

  --help                         Show this message and exit.

Commands:
  full-run
  notarize-app
  notarize-dmg
  pack-dmg
  sign-app
  sign-dmg
  staple-app
  staple-dmg
  status
  unpack-app
```

# Disclaimer
reNotize is a hobby project and not in any way affiliated with Ren'Py. This means that there is no way I can guarantee that it will work at all, or continue to work once it does.
